# Adverse Event Association Use Case

This folder contains code for the adverse event exploration use case shown in the paper. Note that the dataset is not publicly-available but is formatted in the OMOP CDM, so this code can be applied to other OMOP-formatted datasets.